@@ -24,12 +24,15 @@
 
 #include "core.h"
 
+#include <QQmlContext>
+#include <QQmlApplicationEngine>
+
 namespace Minuet
 {
 
 UiController::UiController(QObject *parent)
-    : IUiController(parent),
-      m_mainWindow(new MainWindow(qobject_cast<Core *>(parent)))
+    : IUiController(parent)//,
+      //m_mainWindow(new MainWindow(qobject_cast<Core *>(parent)))
 {
 }
 
@@ -39,9 +42,12 @@ UiController::~UiController()
 
 bool UiController::initialize(Core *core)
 {
-    Q_UNUSED(core);
+    QQmlApplicationEngine *engine = new QQmlApplicationEngine(this);
+    QQmlContext *rootContext = engine->rootContext();
+    rootContext->setContextProperty(QStringLiteral("core"), core);
+    engine->load(QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("qml/Main.qml"))));
 
-    m_mainWindow->show();
+    //m_mainWindow->show();
     return true;
 }
 
